@@ -519,7 +519,7 @@ class AtlasProjection:
             if len(ids) > max_queries:
                 raise Exception(f"Max ids per query is {max_queries}. You sent {len(ids)}.")
         if queries is not None:
-            if not isinstance(queries, np.array):
+            if not isinstance(queries, np.ndarray):
                 raise Exception("`queries` must be an instance of np.array.")
             if queries.shape[0] > max_queries:
                 raise Exception(f"Max vectors per query is {max_queries}. You sent {queries.shape[0]}.")
@@ -1491,27 +1491,3 @@ class AtlasProject(AtlasClass):
                     label_to_datums[label] = []
                 label_to_datums[label].append(item['datum_id'])
         return label_to_datums
-
-    def add_tags(self) -> Dict[str, str]:
-        '''
-        Retrieves back all tags made in the web browser for a specific project and map.
-
-        Returns:
-            A dictionary mapping datum ids to tags.
-        '''
-        # now get the tags
-        datums_and_tags = requests.post(
-            self.atlas_api_path + '/v1/project/tag/read/all_by_datum',
-            headers=self.header,
-            json={
-                'project_id': self.id,
-            },
-        ).json()['results']
-
-        label_to_datums = {}
-        for item in datums_and_tags:
-            for label in item['labels']:
-                if label not in label_to_datums:
-                    label_to_datums[label] = []
-                label_to_datums[label].append(item['datum_id'])
-        return label_to_datums
